@@ -153,13 +153,16 @@ static time_t mktime_from_rfc2616(const char *date) {
  * SYNOPSIS:
  *   double set_clock(
  *                    struct timeval *tvinfo,
- *                    int allow_adj
+ *                    int allow_adj,
+ *                    int ignoreusec
  *                   );
  *
  * ARGUMENTS:
  *   struct timeval *tvinfo  Pointer to time value to set clock to. (GMT/UTC)
  *   int allow_adj           Set to 1 if you want to allow time to be "Slew"'d
  *                           if the OS supports this.
+ *   int ignoreusec          Set to non-zero if you want to ignore the usec
+ *                           field in the `tvinfo' parameter.
  *
  * RETURN VALUE:
  *   This function returns the number of seconds the clock was adjusted.
@@ -170,13 +173,17 @@ static time_t mktime_from_rfc2616(const char *date) {
  *   value as if no adjustment was needed.
  *
  */
-double set_clock(struct timeval *tvinfo, int allow_adj) {
+double set_clock(struct timeval *tvinfo, int allow_adj, int ignoreusec) {
 	struct timeval tvdelta;
 	double retval = 0.0;
 	int chkret = -1;
 
 	gettimeofday(&tvdelta, NULL);
 
+	if (ignoreusec) {
+		tvinfo->tv_usec = tvdelta.tv_usec;
+	}
+
 #ifdef HAVE_ADJTIME
 	if (allow_adj) {
 		tvdelta.tv_sec = tvinfo->tv_sec - tvdelta.tv_sec;
