@@ -11,7 +11,7 @@ struct timeserver_st {
         unsigned int port;
 };
 
-double set_clock(struct timeval *tvinfo, int allow_adj);
+double set_clock(struct timeval *tvinfo, int allow_adj, int ignoreusec);
 struct timeval *htp_calctime(struct timeserver_st *timeservers, unsigned int totaltimeservers, const char *proxyhost, unsigned int proxyport);
 int htp_init(void);
 
