@@ -122,7 +122,7 @@ int htpd_loop(void) {
 		newtime = htp_calctime(timeservers, totaltimeservers, http_proxy, http_proxy_port);
 
 		if (newtime >= 0) {
-			delta = set_clock(newtime, 1);
+			delta = set_clock(newtime, 1, 1);
 		} else {
 			delta = 0.0;
 		}
